@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from django.core.exceptions import ImproperlyConfigured
 from django.views.generic.base import TemplateResponseMixin
-from django.views.generic.list import BaseListView
+from django.views.generic.list import ListView
 
 
 class SingleTableMixin(object):
